/* Copyright (c) 2009 Nordic Semiconductor. All Rights Reserved.
 *
 * The information contained herein is property of Nordic Semiconductor ASA.
 * Terms and conditions of usage are described in detail in NORDIC
 * SEMICONDUCTOR STANDARD SOFTWARE LICENSE AGREEMENT.
 *
 * Licensees are granted free, non-transferable use of the information. NO
 * WARRANTY of ANY KIND is provided. This heading must NOT be removed from
 * the file.
 *
 */

/** @file
* @brief Example template project.
* @defgroup nrf_templates_example Example Template
*
*/

#include <stdbool.h>
#include "nrf_gpio.h"
#include "nrf_drv_twi.h"
#include "bsp.h"
#include "app_error.h"
#include "nrf_drv_config.h"
#include "app_util_platform.h"
#include "nrf_delay.h"

#define TWI1_ENABLED 1
nrf_drv_twi_t  p_twi_instance = NRF_DRV_TWI_INSTANCE(1); // Set up TWI instance 1 with default values

uint8_t my_data[17] = {0};
uint8_t my_data_sr[20] = {0};
static uint8_t thermal_sensor_data[35];
static bool twi_event_flag = false;
static bool tx_ready = false;

//======================== for 12c =============
uint8_t thermal_sensor_device_address = 0xD0; 
uint8_t thermal_sensor_write_address  = 0xD0;
uint8_t thermal_sensor_read_address   = 0x69;
uint8_t thermal_sensor_memory_address = 0x00;


// TWI event handler. Processing TWI events originating from
// nrf_drv_twi_tx()
static void twi_event_handler(nrf_drv_twi_evt_t *evt){
     
    // Light up LED 1 if device found
    if(evt->type == NRF_DRV_TWI_TX_DONE)
    {
        twi_event_flag = 1;
				tx_ready = true;
    }
		else if(evt->type == NRF_DRV_TWI_RX_DONE)
    {
//        twi_event_flag = 1;
//				tx_ready = true;
    }
		else if(evt->type == NRF_DRV_TWI_ERROR)
    {
//        twi_event_flag = 1;
//				tx_ready = true;
    }
}

static void gpio_init()
{
    nrf_gpio_cfg_output(LED_1);
    nrf_gpio_pin_set(LED_1);
}

void twi_init (void)
{
    ret_code_t err_code;
    
    const nrf_drv_twi_config_t twi_config = {
       .scl                = 6,
       .sda                = 5,
       .frequency          = NRF_TWI_FREQ_100K,
       .interrupt_priority = APP_IRQ_PRIORITY_LOW
    };
    
    err_code = nrf_drv_twi_init(&p_twi_instance, &twi_config, twi_event_handler);
    APP_ERROR_CHECK(err_code);
    
    nrf_drv_twi_enable(&p_twi_instance);
}

/**
 * @brief Function for application main entry.
 */
int main(void)
{
    gpio_init();
		bool success;
    uint32_t error_code; 
    ret_code_t ret_code; 

		twi_init();
  
		nrf_delay_ms(100);
	
    const uint8_t dummy_data = 0x00; // Declare some dummy data to use for our search for devices on the TWI bus
    uint8_t rcvd_data;
    // Make a loop iterating through all TWI address listening to a response. x
    // The response will be reported in twi_event_handler()  
    for(uint8_t i=0; i < 0x7f; i++) 
    {
        // Send dummy data on TWI buss on address 'i'
        ret_code = nrf_drv_twi_tx(&p_twi_instance, 0x68, &dummy_data, 1, false);
				APP_ERROR_CHECK(ret_code); // Check for errors in return value
        // Small delay or the driver might not be able to keep up with the fast transmissions
        // There is deffinitely a better way to do this
        nrf_delay_ms(100);  
		}

//while(true){
//	
//for(uint32_t i = 0; i < 50000; i++)
//	{}
//	
//	if(!(nrf_drv_twi_tx(&p_twi_instance, thermal_sensor_device_address, &dummy_data, 1, tx_ready)))
//		{
//			__WFE();  
//			//nrf_delay_ms(10);
//			if(!(nrf_drv_twi_rx(&p_twi_instance,0x80,thermal_sensor_data,35,false)))
//				
//				  my_data[0]=thermal_sensor_data[2];
//					my_data[1]=thermal_sensor_data[3];
//					my_data[2]=thermal_sensor_data[4];
//					my_data[3]=thermal_sensor_data[5];
//					my_data[5]=thermal_sensor_data[6];
//					my_data[6]=thermal_sensor_data[7];
//					my_data[7]=thermal_sensor_data[8];
//					my_data[8]=thermal_sensor_data[9];
//					my_data[9]=thermal_sensor_data[10];
//					my_data[10]=thermal_sensor_data[11];
//					my_data[11]=thermal_sensor_data[12];
//					my_data[12]=thermal_sensor_data[13];
//					my_data[13]=thermal_sensor_data[14];
//					my_data[14]=thermal_sensor_data[15];
//					my_data[15]=thermal_sensor_data[16];
//					my_data[16]=thermal_sensor_data[17];
//					
//					my_data_sr[0]=thermal_sensor_data[18];
//					my_data_sr[1]=thermal_sensor_data[19];
//					my_data_sr[2]=thermal_sensor_data[20];
//					my_data_sr[3]=thermal_sensor_data[21];
//					my_data_sr[5]=thermal_sensor_data[22];
//					my_data_sr[6]=thermal_sensor_data[23];
//					my_data_sr[7]=thermal_sensor_data[24];
//					my_data_sr[8]=thermal_sensor_data[25];
//					my_data_sr[9]=thermal_sensor_data[26];
//					my_data_sr[10]=thermal_sensor_data[27];
//					my_data_sr[11]=thermal_sensor_data[28];
//					my_data_sr[12]=thermal_sensor_data[29];
//					my_data_sr[13]=thermal_sensor_data[30];
//					my_data_sr[14]=thermal_sensor_data[31];
//					my_data_sr[15]=thermal_sensor_data[32];
//					my_data_sr[16]=thermal_sensor_data[33];
//									
//					//tPTAT
//					my_data_sr[17]=thermal_sensor_data[0];
//					my_data_sr[18]=thermal_sensor_data[1];
//					
//					//tPEC
//					my_data_sr[19]=thermal_sensor_data[34];

//		}
		
		

		
    while (true)
    {
        // Do nothing
    }
}
/** @} */
